%define _disable_ld_no_undefined 1

%define pypi_name		scikit-learn
%define src_name		scikit_learn

%global __provides_exclude_from ^(%{python3_sitearch})/.*\\.so$

Summary:	machine learning in Python
Name:		python-%{pypi_name}
Version:	1.6.1
Release:	%mkrel 1
License:	BSD
Group:		Development/Python
Url:		https://pypi.org/project/scikit-learn/
Source0:	%{pypi_source %{src_name}}
BuildRequires:	python3-numpy-devel >= 2
BuildRequires:	pkgconfig(python3)

%description
sklearn is a Python pypi_name that integrates classic machine learning
algorithms with the tightly-knit world of scientific Python packages
(numpy, scipy, matplotlib).

%package -n	python3-%{pypi_name}
Summary:	Python 3 pypi_names for machine learning and data mining
Group:		Development/Python
%{?python_provide:%python_provide python3-%{pypi_name}}

%description -n	python3-%{pypi_name}
sklearn is a Python 3 pypi_name that integrates classic machine learning
algorithms with the tightly-knit world of scientific Python packages
(numpy, scipy, matplotlib).

%prep
%autosetup -n %{src_name}-%{version} -p1

sed -i -e 's|numpy>=2|numpy|' pyproject.toml
find sklearn/metrics/_dist_metrics.pyx.tp -type f | xargs sed -i 's/cdef inline {{INPUT_DTYPE_t}} rdist/cdef {{INPUT_DTYPE_t}} rdist/g'

%generate_buildrequires
%pyproject_buildrequires -p

%build
%pyproject_wheel

%install
%pyproject_install
%pyproject_save_files sklearn

%if %{with check}
%check
# check collection crashes in armv7hl
# https://koji.fedoraproject.org/koji/taskinfo?taskID=74494216
%ifarch armv7hl
%py3_check_import sklearn
%else
export PYTHONDONTWRITEBYTECODE=1
export PYTEST_ADDOPTS='-p no:cacheprovider'
pushd %{buildroot}%{python3_sitearch}
  pytest \
  --deselect "sklearn/datasets/tests/test_openml.py::test_fetch_openml_verify_checksum[True-liac-arff]" \
  --deselect "sklearn/datasets/tests/test_openml.py::test_fetch_openml_verify_checksum[False-liac-arff]" \
  --deselect "sklearn/datasets/tests/test_openml.py::test_fetch_openml_verify_checksum[True-pandas]" \
  --deselect "sklearn/datasets/tests/test_openml.py::test_fetch_openml_verify_checksum[False-pandas]" \
  --deselect "sklearn/covariance/tests/test_covariance.py" \
  --deselect "sklearn/covariance/tests/test_robust_covariance.py" \
  --deselect "sklearn/linear_model/tests/test_bayes.py::test_toy_ard_object" \
  --deselect "sklearn/linear_model/tests/test_bayes.py::test_ard_accuracy_on_easy_problem[42-10-100]" \
  --deselect "sklearn/linear_model/tests/test_bayes.py::test_ard_accuracy_on_easy_problem[42-100-10]" \
  --deselect "sklearn/tests/test_common.py::test_estimators[ARDRegression()-check_estimators_dtypes]" \
  --deselect "sklearn/tests/test_common.py::test_estimators[ARDRegression()-check_regressors_no_decision_function]" \
  --deselect "sklearn/tests/test_common.py::test_estimators[ARDRegression()-check_methods_sample_order_invariance]" \
  --deselect "sklearn/tests/test_common.py::test_estimators[ARDRegression()-check_methods_subset_invariance]" \
  --deselect "sklearn/tests/test_common.py::test_estimators[ARDRegression()-check_fit2d_1feature]" \
  --deselect "sklearn/tests/test_common.py::test_estimators[ARDRegression()-check_dont_overwrite_parameters]" \
  --deselect "sklearn/tests/test_common.py::test_estimators[ARDRegression()-check_fit2d_predict1d]" \
  --deselect "sklearn/tests/test_common.py::test_estimators[EllipticEnvelope()-check_fit2d_1feature]" \
  --deselect "sklearn/tests/test_common.py::test_estimators[EmpiricalCovariance()-check_fit2d_1feature]" \
  --deselect "sklearn/tests/test_common.py::test_estimators[FastICA()-check_methods_sample_order_invariance]" \
  --deselect "sklearn/tests/test_common.py::test_estimators[FastICA()-check_methods_subset_invariance]" \
  --deselect "sklearn/tests/test_common.py::test_estimators[FastICA()-check_fit2d_1feature]" \
  --deselect "sklearn/tests/test_common.py::test_estimators[FastICA()-check_dict_unchanged]" \
  --deselect "sklearn/tests/test_common.py::test_estimators[FastICA()-check_dont_overwrite_parameters]" \
  --deselect "sklearn/tests/test_common.py::test_estimators[FastICA()-check_fit2d_predict1d]" \
  --deselect "sklearn/tests/test_common.py::test_estimators[KernelPCA()-check_fit2d_1sample]" \
  --deselect "sklearn/tests/test_common.py::test_estimators[LedoitWolf()-check_fit2d_1feature]" \
  --deselect "sklearn/tests/test_common.py::test_estimators[MinCovDet()-check_fit2d_1feature]" \
  --deselect "sklearn/tests/test_common.py::test_estimators[OAS()-check_fit2d_1feature]" \
  --deselect "sklearn/tests/test_common.py::test_estimators[RidgeCV()-check_fit2d_1sample]" \
  --deselect "sklearn/tests/test_common.py::test_estimators[RidgeClassifierCV()-check_fit2d_1sample]" \
  --deselect "sklearn/tests/test_common.py::test_estimators[ShrunkCovariance()-check_fit2d_1feature]" \
  --deselect "sklearn/utils/tests/test_validation.py::test_check_is_fitted_with_attributes[list]" \
  --deselect "sklearn/utils/tests/test_validation.py::test_check_is_fitted" \
%ifarch ppc64le
  --deselect "sklearn/tests/test_calibration.py::test_calibrated_classifier_cv_zeros_sample_weights_equivalence[True-isotonic]" \
%endif
  sklearn
popd
%endif
%endif

%files -n python3-%{pypi_name} -f %{pyproject_files}
%doc examples/
%doc COPYING sklearn/svm/src/liblinear/COPYRIGHT


%changelog
* Mon Mar 03 2025 daviddavid <daviddavid> 1.6.1-1.mga10
+ Revision: 2159165
- new version: 1.6.1
- new version: 1.5.2
+ wally <wally>
- rebuild for python3.13

* Thu Sep 26 2024 daviddavid <daviddavid> 1.4.2-4.mga10
+ Revision: 2101381
- rebuild against numpy 2

* Tue Jun 18 2024 daviddavid <daviddavid> 1.4.2-3.mga10
+ Revision: 2074757
- backport/rebase upstream patch to fix CVE-2024-5206 (mga#33307)

* Sat Apr 27 2024 daviddavid <daviddavid> 1.4.2-2.mga10
+ Revision: 2061290
- new version: 1.4.2

* Thu Feb 01 2024 papoteur <papoteur> 1.4.0-2.mga10
+ Revision: 2036596
- rebuild for python 3.12
- use pyproject macros

* Sun Sep 18 2022 guillomovitch <guillomovitch> 1.1.2-2.mga9
+ Revision: 1889958
- fix build
+ neoclust <neoclust>
- Rebuild with fixed file list
- New version 	1.1.2

* Wed Apr 06 2022 umeabot <umeabot> 1.0.2-3.mga9
+ Revision: 1846134
- Mageia 9 Mass Rebuild

* Tue Feb 22 2022 mrambo3501 <mrambo3501> 1.0.2-2.mga9
+ Revision: 1782682
- rebuild for python-3.10

* Mon Jan 24 2022 guillomovitch <guillomovitch> 1.0.2-1.mga9
+ Revision: 1769572
- new version 1.0.2

* Sun Sep 26 2021 guillomovitch <guillomovitch> 1.0-1.mga9
+ Revision: 1746600
- new version 1.0

* Tue Mar 23 2021 guillomovitch <guillomovitch> 0.24.1-2.mga9
+ Revision: 1708521
- rebuild for python 3.9

* Fri Feb 26 2021 guillomovitch <guillomovitch> 0.24.1-1.mga9
+ Revision: 1692372
- new version 0.24.1

* Mon Aug 31 2020 guillomovitch <guillomovitch> 0.23.2-1.mga8
+ Revision: 1620457
- new version 0.23.2

* Wed Jul 15 2020 daviddavid <daviddavid> 0.23.1-1.mga8
+ Revision: 1606205
- new version: 0.23.1

* Sat Apr 18 2020 guillomovitch <guillomovitch> 0.22.2.post1-1.mga8
+ Revision: 1568825
- fix package name: it is python-scikit-learn, not python-scikits-learn
- fix package name
- new version 0.22.2.post1

* Sun Feb 16 2020 umeabot <umeabot> 0.21.3-2.mga8
+ Revision: 1534495
- Mageia 8 Mass Rebuild

* Fri Oct 04 2019 daviddavid <daviddavid> 0.21.3-1.mga8
+ Revision: 1449225
- new version: 0.21.3
- rebuild for python3.8
- drop python2 support

* Sat Mar 02 2019 daviddavid <daviddavid> 0.20.3-1.mga7
+ Revision: 1371094
- new version: 0.20.3

* Fri Jan 11 2019 daviddavid <daviddavid> 0.20.2-1.mga7
+ Revision: 1354984
- new version: 0.20.2
- rebuild for new Python 3.7

* Sun Sep 23 2018 umeabot <umeabot> 0.19.1-4.mga7
+ Revision: 1300591
- Mageia 7 Mass Rebuild
+ kekepower <kekepower>
- Create and use py3dir

* Wed Mar 21 2018 kekepower <kekepower> 0.19.1-3.mga7
+ Revision: 1211140
- Use python_provide
- Use python[2,3]dist

* Thu Jan 11 2018 daviddavid <daviddavid> 0.19.1-2.mga7
+ Revision: 1192343
- new version: 0.19.1

* Sun Oct 15 2017 joequant <joequant> 0.19.0-2.mga7
+ Revision: 1172136
- add source
- upgrade to 0.19.0

* Sat Aug 05 2017 pterjan <pterjan> 0.17.1-4.mga7
+ Revision: 1135620
- Rebuild for python 3.6

* Thu May 26 2016 daviddavid <daviddavid> 0.17.1-3.mga6
+ Revision: 1018773
- rebuild against fixed python-scipy

* Sun Feb 21 2016 daviddavid <daviddavid> 0.17.1-2.mga6
+ Revision: 975116
- disable tests on arm as they fails

* Sun Feb 21 2016 daviddavid <daviddavid> 0.17.1-1.mga6
+ Revision: 975071
- new version: 0.17.1
- use new python macros
+ umeabot <umeabot>
- Mageia 6 Mass Rebuild

* Thu Nov 12 2015 daviddavid <daviddavid> 0.17-1.mga6
+ Revision: 902760
- new version: 0.17

* Fri Oct 09 2015 daviddavid <daviddavid> 0.16.1-1.mga6
+ Revision: 888208
- new version: 0.16.1
- add an URL for Source
- rebuild for python 3.5
- use new python macros

* Wed Oct 15 2014 umeabot <umeabot> 0.15.2-4.mga5
+ Revision: 743912
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 0.15.2-3.mga5
+ Revision: 729715
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 0.15.2-2.mga5
+ Revision: 688318
- Mageia 5 Mass Rebuild

* Mon Sep 08 2014 grenoya <grenoya> 0.15.2-1.mga5
+ Revision: 673766
- new version 0.15.2

* Mon Sep 08 2014 grenoya <grenoya> 0.15.1-1.mga5
+ Revision: 673553
- new version 0.15.1
- add python3 support
- re-enable tests
+ pterjan <pterjan>
- Rebuild for new Python

* Tue Oct 22 2013 umeabot <umeabot> 0.14.1-3.mga4
+ Revision: 544151
- Mageia 4 Mass Rebuild

* Tue Oct 15 2013 pterjan <pterjan> 0.14.1-2.mga4
+ Revision: 499330
- Rebuild to add different pythonegg provides for python 2 and 3

* Fri Oct 11 2013 grenoya <grenoya> 0.14.1-1.mga4
+ Revision: 495506
- new version 0.14.1

* Sun Jan 13 2013 umeabot <umeabot> 0.12-2.mga3
+ Revision: 379470
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed Jan 09 2013 grenoya <grenoya> 0.12-1.mga3
+ Revision: 344035
- disable tests
- new version 0.12
- fix tests (correctly this time)

* Tue Aug 21 2012 grenoya <grenoya> 0.11-1.mga3
+ Revision: 282985
- comment tests (can't pass on BS as it needs to be installed first)
- new version 0.11
- remove patch #0 (merged upstream)
- move to nosetests tests (as indicated by upstream people)

* Fri Sep 23 2011 grenoya <grenoya> 0.9-1.mga2
+ Revision: 147024
- new version 0.9
- fix url

* Sun Jul 17 2011 grenoya <grenoya> 0.8.1-1.mga2
+ Revision: 125407
- clean spec
- add python-nose and python-matplotlib as BuildRequires
- add back check part
- upgrade sources
- rewrite %%file part
- imported package python-scikits-learn

